==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "You commented" : "Ви прокоментували",
    "%1$s commented" : "%1$s прокоментовано",
    "{author} commented" : "{author} прокоментував",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментів</strong> для файлів",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вас згадали в \"{file}\" у коментарі користувача, який згодом було видалено",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} згадав вас у коментарі до \"{file}\"",
    "Files app plugin to add comments to files" : "Додаток до застосунку Файли (Files) для коментування файлів",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Вилучити коментар",
    "Cancel edit" : "Скасувати редагування",
    "Post comment" : "Опублікувати коментар",
    "No comments yet, start the conversation!" : "Коментарі відсутні, почніть бесіду!",
    "No more messages" : "Більше жодних повідомлень",
    "Retry" : "Ще раз",
    "Unable to load the comments list" : "Не вдалося завантажити список коментарів",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитаний коментар","%n непрочитаних коментарів","%n непрочитаних коментарів","%n непрочитаних коментарів"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} новий коментар","{unread} нових коментарів","{unread} нових коментарів","{unread} нових коментарів"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Під час редагування коментаря сталася помилка",
    "Comment deleted" : "Коментар вилучено",
    "An error occurred while trying to delete the comment" : "Під час спроби видалити коментар сталася помилка",
    "An error occurred while trying to create the comment" : "Під час створення коментаря сталася помилка",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Вас було згадано у “{file}” у коментарі користувача, якого було пізніше вилучено",
    "{user} mentioned you in a comment on “{file}”" : "{user} згадав Вас у коментарі про “{file}”"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/comments/l10n/uk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Коментарі",
    "You commented" : "Ви прокоментували",
    "%1$s commented" : "%1$s прокоментовано",
    "{author} commented" : "{author} прокоментував",
    "You commented on %1$s" : "Ви прокоментували на %1$s",
    "You commented on {file}" : "Ви прокоментували {file}",
    "%1$s commented on %2$s" : "%1$s прокоментовано у %2$s",
    "{author} commented on {file}" : "{author} прокоментував {file}",
    "<strong>Comments</strong> for files" : "<strong>Коментів</strong> для файлів",
    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Вас згадали в \"{file}\" у коментарі користувача, який згодом було видалено",
    "{user} mentioned you in a comment on \"{file}\"" : "{user} згадав вас у коментарі до \"{file}\"",
    "Files app plugin to add comments to files" : "Плаґін до застосунку и\"Файли\" для додавання коментарів до файлів",
    "Edit comment" : "Редагувати коментар",
    "Delete comment" : "Вилучити коментар",
    "Cancel edit" : "Скасувати редагування",
    "Post comment" : "Опублікувати коментар",
    "No comments yet, start the conversation!" : "Коментарі відсутні, почніть бесіду!",
    "No more messages" : "Більше жодних повідомлень",
    "Retry" : "Ще раз",
    "Unable to load the comments list" : "Не вдалося завантажити список коментарів",
    "_%n unread comment_::_%n unread comments_" : ["%n непрочитаний коментар","%n непрочитаних коментарів","%n непрочитаних коментарів","%n непрочитаних коментарів"],
    "_1 new comment_::_{unread} new comments_" : ["{unread} новий коментар","{unread} нових коментарів","{unread} нових коментарів","{unread} нових коментарів"],
    "Comment" : "Коментар",
    "An error occurred while trying to edit the comment" : "Під час редагування коментаря сталася помилка",
    "Comment deleted" : "Коментар вилучено",
    "An error occurred while trying to delete the comment" : "Під час спроби видалити коментар сталася помилка",
    "An error occurred while trying to create the comment" : "Під час створення коментаря сталася помилка",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Вас було згадано у “{file}” у коментарі користувача, якого було пізніше вилучено",
    "{user} mentioned you in a comment on “{file}”" : "{user} згадав Вас у коментарі про “{file}”"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
